@@ -255,7 +255,7 @@ covid19.JHU.data <- function(case='aggregated', local.data=FALSE, debrief=FALSE)
                         # aggregated data
                         # 'aggregated'   = paste0(LOCAL.repo,format(Sys.Date()-1,format="%m-%d-%Y"),".csv"),
 			# 'aggregated'   = paste0(LOCAL.repo,"03-24-2020.csv"),
-			'aggregated'   = system.file("extdata","05-01-2020.csv", package=covid19.pckg, mustWork = TRUE),
+			'aggregated'   = system.file("extdata","07-04-2020.csv", package=covid19.pckg, mustWork = TRUE),
                         # GLOBAL TimeSeries cases
                         # 'ts-confirmed' = paste0(LOCAL.repo,"time_series_covid19_confirmed_global.csv"),
                         # 'ts-deaths'    = paste0(LOCAL.repo,"time_series_covid19_deaths_global.csv"),
@@ -344,19 +344,20 @@ covid19.JHU.data <- function(case='aggregated', local.data=FALSE, debrief=FALSE)
 ###########################################################################
 
 
-covid19.Toronto.data <- function(data.fmt="TS",local.data=FALSE,debrief=FALSE) {
+covid19.Toronto.data <- function(data.fmt="TS",local.data=FALSE,debrief=FALSE, OLD.fmt=FALSE) {
 #' function to import data from the city of Toronto, ON - Canada
 #' as reported by the City of Toronto
 #'	https://www.toronto.ca/home/covid-19/covid-19-latest-city-of-toronto-news/covid-19-status-of-cases-in-toronto/
 #'
-#' @param  data.fmt  "TS" for TimeSeries or "original"
+#' @param  data.fmt  "TS" for TimeSeries of cumulative cases or "original" for the data as reported in the google-document with multiple sheets
 #' @param  local.data  boolean flag to indicate whether the data will be read from the local repo, in case of connectivity issues or data integrity
 #' @param  debrief  boolean specifying whether information about the read data is going to be displayed in screen
+#' @param  OLD.fmt  boolean flag to specify if the data is being read in an old format
 #'
 #' @return  a dataframe (or a list in the case of "original") with the latest data reported for the city of Toronto, ON - Canada
 #'
 #' @importFrom  utils  download.file
-#' @importFrom  readxl  read_excel
+#' @importFrom  readxl  excel_sheets read_excel
 #'
 #' @export
 #'
@@ -366,12 +367,17 @@ covid19.Toronto.data <- function(data.fmt="TS",local.data=FALSE,debrief=FALSE) {
 	if (!local.data) {
 		# Google drive URL, with "City of Toronto" data
 		city.of.Toronto.data <- "https://drive.google.com/uc?export=download&id=1euhrML0rkV_hHF1thiA0G5vSSeZCqxHY"
-		# temporary file to retrieve data
-		Tor.xlsx.file <- normalizePath(file.path(tempdir(), "covid19-toronto.xslx"))
+		# temporary file to retrieve data, does not exist yet ==> mustwork=FALSE to avoid warning message
+		Tor.xlsx.file <- normalizePath(file.path(tempdir(), "covid19-toronto.xslx"), mustWork=FALSE)
 		header('',paste("Accessing file from...",Tor.xlsx.file))
 
 		# save excel file
-		download.file(city.of.Toronto.data, destfile=Tor.xlsx.file)
+		#if (capabilities('libcurl')) {
+		#	dwnld.method <- 'libcurl'
+		#} else {
+		#	stop("curl/libcurl; needed to download data from internet")
+		#}
+		download.file(city.of.Toronto.data, destfile=Tor.xlsx.file, mode = 'wb' )	#method=dwnld.method)
         } else {
                 # use local data
 		covid19.pckg <- 'covid19.analytics'
@@ -382,8 +388,30 @@ covid19.Toronto.data <- function(data.fmt="TS",local.data=FALSE,debrief=FALSE) {
 
 
 	if (file.exists(Tor.xlsx.file)) {
+		###~~~~~~
+		print(Tor.xlsx.file)
+		###~~~~~~
+		# obtain names of sheets
+		lst.sheets <- excel_sheets(Tor.xlsx.file)
+
+		print(lst.sheets)
+
+		# if only "TS" identify corresponding sheet
+		key.wrd <- "Cumulative Cases by Reported"
+		tgt.sheet <- pmatch(key.wrd,lst.sheets)
+
 		# read data
-		toronto <- read_excel(Tor.xlsx.file,sheet=7)
+		if (toupper(data.fmt)=="TS") {
+			header('',"Reading TimeSeries data...")
+			toronto <- read_excel(Tor.xlsx.file,sheet=tgt.sheet)
+		} else {
+			header('',"Collecting all data reported...")
+			toronto <- list()
+			# iterate on each sheet...
+			for (sht in lst.sheets) {
+				toronto[[sht]] <- read_excel(Tor.xlsx.file,sheet=sht)
+			}
+		}
 
 		# clean-up after reading the file only if it isn't the local repo
 		if (!local.data) file.remove(Tor.xlsx.file)
@@ -396,16 +424,74 @@ covid19.Toronto.data <- function(data.fmt="TS",local.data=FALSE,debrief=FALSE) {
 		}
 	}
 
-	# Convert into TS format
 
-	reported.dates <- rev(as.Date(toronto[[1]]))
-	reported.cases <- rev(toronto[[2]])
+	if (toupper(data.fmt)=="TS") {
+		## PREVIOUS FORMAT -- cases identified in 3 categories: deaths, active, resolved
+		if (OLD.fmt) {
+			# identify columns
+			cat.col <- 2
+			date.col <- 1
+			nbr.col <- 3
 
-	tor.data <- cbind(data.frame("Canada","Toronto, ON",43.6532,79.3832),
-					rbind(as.integer(reported.cases)) )
+			# filter categories
+			categs <- unique(toronto[[cat.col]])
+			# sort them alphabetically
+			categs <- sort(categs)
 
-	names(tor.data) <- c("Country.Region","Province.City","Lat","Long",
-				as.character(reported.dates))
+			# check for inconsistencies in data, ie. missing categories
+			if (length(categs) != 3) {
+				stop("There supppose to be at least three categories/status within the data!\n This may represent some inconsistency with the datasets please contact the author of the package.")
+			}
+
+			# break into different categories
+			data.per.categ <- split(toronto, toronto[[cat.col]])
+
+			# Convert into TS format
+			x <- data.frame()
+			for (i in categs) {
+				reported.dates <- rev(unique(as.Date(data.per.categ[[i]][[date.col]])))
+				x <- rbind(x,rev(data.per.categ[[i]][[nbr.col]]))
+			}
+		###########
+		} else {
+		###########
+			date.col <- 1
+			categs <- names(toronto[2:4])
+
+			# get the dates...
+			reported.dates <- rev(unique(as.Date(toronto[,date.col][[1]])))
+
+			x <- data.frame()
+			# Convert into TS format
+			for (i in categs) {
+				#reported.dates <- rev(unique(as.Date(data.per.categ[[i]][[date.col]])))
+				#x <- rbind(x,rev(data.per.categ[[i]][[nbr.col]]))
+				data.per.categ <- toronto[,i]
+				x <- rbind(x,rev(data.per.categ[[1]]))
+			}
+		}
+
+		# add category
+		x <- cbind(x, categs)
+
+		## OLD WAY!!!! ###
+		#reported.dates <- rev(as.Date(toronto[[date.col]]))
+		#reported.cases <- rev(toronto[[nbr.col]])
+		#
+		#tor.data <- cbind(data.frame("Canada","Toronto, ON",43.6532,79.3832),
+		#				rbind(as.integer(reported.cases)) )
+		##################
+
+		tor.data <- cbind(data.frame("Canada","Toronto, ON",43.6532,79.3832), x)
+
+		names(tor.data) <- c("Country.Region","Province.City","Lat","Long",
+					as.character(reported.dates),
+					"status")
+	} else {
+		# ALL DATA
+		tor.data <- toronto
+		print(names(tor.data))
+	}
 
 	# debrief...
 	debriefing(tor.data,debrief)
